@@ -1,8 +1,12 @@
 from __future__ import generator_stop
 
 from collections import UserDict, defaultdict
+from collections.abc import Mapping, MutableMapping  # noqa: F401
 from copy import deepcopy
-from typing import Any, Callable, Dict, Hashable, Iterable, Iterator, List, Mapping, Tuple, TypeVar, Union
+from typing import Any, Callable, Dict, Hashable, Iterable, Iterator, List
+from typing import Mapping as MappingT
+from typing import MutableMapping as MutableMappingT
+from typing import Tuple, TypeVar, Union
 
 T = TypeVar("T")
 U = TypeVar("U")
@@ -22,6 +26,54 @@ def flatten(d: Union[Dict[T, U], List[U], Tuple[U, ...]]) -> Iterator[U]:
         raise TypeError(f"Unsupported type: {type(d)}")
 
 
+def _flatten_keys(d: Dict[Any, Any], out: Dict[tuple, Any], path: tuple) -> None:
+
+    for k, v in d.items():
+        if isinstance(v, dict):
+            _flatten_keys(v, out, path + (k,))
+        else:
+            out[path + (k,)] = v
+
+
+def flatten_keys(d: Dict[Any, Any]) -> Dict[tuple, Any]:
+    out: Dict[tuple, Any] = {}
+    _flatten_keys(d, out, ())
+    return out
+
+
+def rec_update(d: MutableMappingT, u: MappingT) -> None:
+
+    """Updates dict `d` recursively with values from `u`.
+    Requires `setdefault` method.
+    """
+
+    if not isinstance(d, MutableMapping) or not isinstance(u, Mapping):
+        raise TypeError("All arguments must be mappings")
+
+    for k, v in u.items():
+        if isinstance(v, Mapping):
+            rec_update(d.setdefault(k, {}), v)
+        else:
+            d[k] = v
+
+
+def rec_update_mod(d: Any, u: MappingT) -> None:
+
+    """Similar to `rec_update`, except that `d` doesn't require the `setdefault` method."""
+
+    for k, v in u.items():
+        if isinstance(v, Mapping):
+            try:
+                sub = d[k]
+            except KeyError:
+                # d might not store a reference to the original object, thus don't do `sub = d[k] = {}`
+                d[k] = {}
+                sub = d[k]
+            rec_update_mod(sub, v)
+        else:
+            d[k] = v
+
+
 def get_one_of(d: Dict[T, U], keys: Iterable[T]) -> Tuple[T, U]:
 
     """Returns the (key, value) pair of the first key of `keys` found in `d`."""
@@ -49,7 +101,7 @@ def get_available(d: Dict[T, U], keys: Iterable[T]) -> Iterator[Tuple[T, U]]:
             pass
 
 
-def subdict(d: Mapping[T, U], it: Iterable[T]) -> Dict[T, U]:
+def subdict(d: MappingT[T, U], it: Iterable[T]) -> Dict[T, U]:
 
     """Uses the elements of `it` as keys to extract a new sub-dictionary.
     Raises if not all keys in `it` are available.
@@ -59,7 +111,7 @@ def subdict(d: Mapping[T, U], it: Iterable[T]) -> Dict[T, U]:
 
 
 # was: mapdict, mapget
-def mapmap(d: Mapping[T, U], it: Iterable[T]) -> Iterator[U]:
+def mapmap(d: MappingT[T, U], it: Iterable[T]) -> Iterator[U]:
     """Returns all the values of `d` for the keys in `it`.
     Raises for missing keys.
     """
@@ -81,7 +133,7 @@ def valuemap(func: Callable[[U], V], d: Dict[T, U]) -> Dict[T, V]:
     return {k: func(v) for k, v in d.items()}
 
 
-def itemgetter(it: Iterable[T]) -> Callable[[Mapping[T, U]], Iterator[U]]:
+def itemgetter(it: Iterable[T]) -> Callable[[MappingT[T, U]], Iterator[U]]:
 
     """Similar to `operator.itemgetter` except that it always expects and returns iterables.
     Compare `mapmap`
@@ -90,7 +142,7 @@ def itemgetter(it: Iterable[T]) -> Callable[[Mapping[T, U]], Iterator[U]]:
     return lambda d: (d[i] for i in it)
 
 
-def subdictdefault(d: Mapping[T, U], it: Iterable[T], default: V = None) -> Dict[T, Union[U, V]]:
+def subdictdefault(d: MappingT[T, U], it: Iterable[T], default: V = None) -> Dict[T, Union[U, V]]:
 
     """Uses the elements of `it` as keys to extract a new sub-dictionary."""
 
@@ -218,7 +270,7 @@ def get_schema_simple(d: Iterable[dict]) -> dict:
 
 
 # was: zipmap
-def zipget(objs: Iterable[Mapping[T, U]], keys: Iterable[T]) -> Iterator[U]:
+def zipget(objs: Iterable[MappingT[T, U]], keys: Iterable[T]) -> Iterator[U]:
 
     """Gets a list of keys from a list of mappings.
         zipget([[1, 2], [3, 4]], [0, 1]) -> (1, 4)
