@@ -1,6 +1,6 @@
 from __future__ import generator_stop
 
-FILE_DEVICE_SCSI = 0x0000001b
+FILE_DEVICE_SCSI = 0x0000001B
 
 IOCTL_SCSI_EXECUTE_IN = (FILE_DEVICE_SCSI << 16) + 0x0011
 IOCTL_SCSI_EXECUTE_OUT = (FILE_DEVICE_SCSI << 16) + 0x0012
@@ -18,6 +18,6 @@ IOCTL_SCSI_MINIPORT_RETURN_STATUS = (FILE_DEVICE_SCSI << 16) + 0x0506
 IOCTL_SCSI_MINIPORT_ENABLE_DISABLE_AUTOSAVE = (FILE_DEVICE_SCSI << 16) + 0x0507
 IOCTL_SCSI_MINIPORT_SAVE_ATTRIBUTE_VALUES = (FILE_DEVICE_SCSI << 16) + 0x0508
 IOCTL_SCSI_MINIPORT_EXECUTE_OFFLINE_DIAGS = (FILE_DEVICE_SCSI << 16) + 0x0509
-IOCTL_SCSI_MINIPORT_ENABLE_DISABLE_AUTO_OFFLINE = (FILE_DEVICE_SCSI << 16) + 0x050a
-IOCTL_SCSI_MINIPORT_READ_SMART_LOG = (FILE_DEVICE_SCSI << 16) + 0x050b
-IOCTL_SCSI_MINIPORT_WRITE_SMART_LOG = (FILE_DEVICE_SCSI << 16) + 0x050c
+IOCTL_SCSI_MINIPORT_ENABLE_DISABLE_AUTO_OFFLINE = (FILE_DEVICE_SCSI << 16) + 0x050A
+IOCTL_SCSI_MINIPORT_READ_SMART_LOG = (FILE_DEVICE_SCSI << 16) + 0x050B
+IOCTL_SCSI_MINIPORT_WRITE_SMART_LOG = (FILE_DEVICE_SCSI << 16) + 0x050C
